iotools.write_expr_to_ly_and_to_pdf_and_show
============================================

.. autofunction:: abjad.tools.iotools.write_expr_to_ly_and_to_pdf_and_show.write_expr_to_ly_and_to_pdf_and_show
